@@ -930,7 +930,7 @@ static int __init kernel_init(void * unused)
 	 * We need to ensure that the filesystem is ready by this point, wait for
 	 * async_populate_rootfs to complete.
 	 */
-	async_synchronize_full_domain(&populate_rootfs_domain);
+	populate_rootfs_wait();
 
 	/*
 	 * check if there is an early userspace init.  If yes, let it do all
